@@ -1,4 +1,4 @@
 from botPlus.botPlus import yellow
 from botPlus.botPlus import green
 from botPlus.botPlus import red
-from botPlus.botPlus import botUtils
+from botPlus.botPlus import bot
